@@ -1,4 +1,5 @@
 from vdocipher.resources.annotate import Annotate
+from vdocipher.resources.ip_geo_rule import IPGeoRule
 from vdocipher.resources.license_rules import LicenseRules
 from vdocipher.resources.otp import OTP
 from vdocipher.tests.conftest import BaseTest
@@ -42,3 +43,23 @@ class TestOTP(BaseTest):
         assert isinstance(otp, OTP)
         assert otp.otp
         assert otp.playback_info
+
+    def test_create_opt_with_white_list_href(self, video):
+        otp = self.vdocipher.OTP(white_list_href="vdocipher.com").create(video_id=video.id)
+
+        assert isinstance(otp, OTP)
+        assert otp.otp
+        assert otp.playback_info
+
+    def test_create_opt_with_ip_geo_rules(self, video):
+        geo_rules = IPGeoRule(
+            actions=True,
+            ip_set=[],
+            country_set=["IN", "GB"]
+        )
+        geo_rules_list = [geo_rules]
+        otp = self.vdocipher.OTP(ip_geo_rules=geo_rules_list).create(video_id=video.id)
+
+        assert isinstance(otp, OTP)
+        assert otp.otp
+        assert otp.playback_info
